@@ -1,9 +1,7 @@
-# flake8: noqa
-import functools
-import sys
-import codecs
+# ruff: noqa: F401
 import array
-from functools import reduce
+import codecs
+import functools
 
 import numpy as np
 
@@ -115,7 +113,7 @@ def ensure_contiguous_ndarray_like(buf, max_buffer_size=None, flatten=True) -> N
         raise ValueError("an array with contiguous memory is required")
 
     if max_buffer_size is not None and arr.nbytes > max_buffer_size:
-        msg = "Codec does not support buffers of > {} bytes".format(max_buffer_size)
+        msg = f"Codec does not support buffers of > {max_buffer_size} bytes"
         raise ValueError(msg)
 
     return arr
