@@ -1,14 +1,13 @@
+import importlib
 import os.path
-import pkgutil
 import sys
+from multiprocessing import Process
 
 import pytest
 
-from multiprocessing import Process
-
 import numcodecs.registry
 
-if not pkgutil.find_loader("importlib_metadata"):  # pragma: no cover
+if not importlib.util.find_spec("importlib_metadata").loader:  # pragma: no cover
     pytest.skip(
         "This test module requires importlib_metadata to be installed",
         allow_module_level=True,
