@@ -1,25 +1,22 @@
 import unittest
 
-
 import numpy as np
 import pytest
 
-
 try:
     from numcodecs.msgpacks import MsgPack
-except ImportError:  # pragma: no cover
-    raise unittest.SkipTest("msgpack not available")
+except ImportError as e:  # pragma: no cover
+    raise unittest.SkipTest("msgpack not available") from e
 
 
 from numcodecs.tests.common import (
-    check_config,
-    check_repr,
-    check_encode_decode_array,
     check_backwards_compatibility,
+    check_config,
+    check_encode_decode_array,
+    check_repr,
     greetings,
 )
 
-
 # object array with strings
 # object array with mix strings / nans
 # object array with mix of string, int, float
